@@ -11,7 +11,7 @@ def run_tests(test_labels, verbosity=1, interactive=True, extra_tests=[]):
     figleaf.start()
     test_results = django_test_runner(test_labels, verbosity, interactive, extra_tests)
     figleaf.stop()
-    if not os.path.isdir(os.path.join("temp", "figleaf")): os.mkdir(os.path.join("temp", "figleaf"))
+    if not os.path.isdir(os.path.join("temp", "figleaf")): os.makedirs(os.path.join("temp", "figleaf"))
     file_name = "temp/figleaf/test_output.figleaf"
     figleaf.write_coverage(file_name)
     output = commands.getoutput("figleaf2html " + file_name + " --output-directory=temp/figleaf")
